==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/content/logistics/packager/PackagerBlock.java <==
package com.zurrtum.create.content.logistics.packager;

import com.zurrtum.create.AllBlockEntityTypes;
import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.AllItems;
import com.zurrtum.create.AllSoundEvents;
import com.zurrtum.create.api.entity.FakePlayerHandler;
import com.zurrtum.create.content.equipment.wrench.IWrenchable;
import com.zurrtum.create.content.logistics.box.PackageItem;
import com.zurrtum.create.foundation.advancement.AdvancementBehaviour;
import com.zurrtum.create.foundation.block.*;
import com.zurrtum.create.foundation.blockEntity.behaviour.BlockEntityBehaviour;
import com.zurrtum.create.foundation.blockEntity.behaviour.inventory.InvManipulationBehaviour;
import com.zurrtum.create.foundation.item.ItemHelper;
import com.zurrtum.create.infrastructure.items.ItemInventoryProvider;
import net.minecraft.class_10;
import net.minecraft.class_1263;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2561;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_8235;
import net.minecraft.class_9904;
import org.jetbrains.annotations.Nullable;

public class PackagerBlock extends WrenchableDirectionalBlock implements IBE<PackagerBlockEntity>, IWrenchable, ItemInventoryProvider<PackagerBlockEntity>, NeighborChangeListeningBlock, WeakPowerControlBlock, NeighborUpdateListeningBlock {

    public static final class_2746 POWERED = class_2741.field_12484;
    public static final class_2746 LINKED = class_2746.method_11825("linked");

    public PackagerBlock(class_2251 properties) {
        super(properties);
        class_2680 defaultBlockState = method_9564();
        if (defaultBlockState.method_28498(LINKED))
            defaultBlockState = defaultBlockState.method_11657(LINKED, false);
        method_9590(defaultBlockState.method_11657(POWERED, false));
    }

    @Override
    public class_1263 getInventory(class_1936 world, class_2338 pos, class_2680 state, PackagerBlockEntity blockEntity, class_2350 context) {
        return blockEntity.inventory;
    }

    @Override
    public void method_9567(class_1937 pLevel, class_2338 pPos, class_2680 pState, class_1309 pPlacer, class_1799 pStack) {
        super.method_9567(pLevel, pPos, pState, pPlacer, pStack);
        AdvancementBehaviour.setPlacedBy(pLevel, pPos, pPlacer);
    }

    @Override
    public class_2680 method_9605(class_1750 context) {
        class_2350 preferredFacing = null;
        for (class_2350 face : context.method_7718()) {
            class_2338 pos = context.method_8037().method_10093(face);
            class_2586 be = context.method_8045().method_8321(pos);
            if (be instanceof PackagerBlockEntity)
                continue;
            if (be != null && be.method_11002() && ItemHelper.getInventory(be.method_10997(), pos, null, be, null) != null) {
                preferredFacing = face.method_10153();
                break;
            }
        }

        class_1657 player = context.method_8036();
        if (preferredFacing == null) {
            class_2350 facing = context.method_7715();
            preferredFacing = player != null && player.method_5715() ? facing : facing.method_10153();
        }

        if (player != null && !(FakePlayerHandler.has(player))) {
            if (context.method_8045().method_8320(context.method_8037().method_10093(preferredFacing.method_10153()))
                .method_27852(AllBlocks.PORTABLE_STORAGE_INTERFACE)) {
                player.method_7353(class_2561.method_43471("create.packager.no_portable_storage"), true);
                return null;
            }
        }

        return super.method_9605(context).method_11657(POWERED, context.method_8045().method_49803(context.method_8037()))
            .method_11657(field_10927, preferredFacing);
    }

    @Override
    protected class_1269 method_55765(
        class_1799 stack,
        class_2680 state,
        class_1937 level,
        class_2338 pos,
        class_1657 player,
        class_1268 hand,
        class_3965 hitResult
    ) {
        if (stack.method_31574(AllItems.WRENCH))
            return class_1269.field_52423;
        if (stack.method_31574(AllItems.FACTORY_GAUGE))
            return class_1269.field_52423;
        if (stack.method_31574(AllItems.STOCK_LINK) && !(state.method_28498(LINKED) && state.method_11654(LINKED)))
            return class_1269.field_52423;
        if (stack.method_31574(AllItems.PACKAGE_FROGPORT))
            return class_1269.field_52423;

        if (onBlockEntityUseItemOn(
            level, pos, be -> {
                if (be.heldBox.method_7960()) {
                    if (be.animationTicks > 0)
                        return class_1269.field_5812;
                    if (PackageItem.isPackage(stack)) {
                        if (level.method_8608())
                            return class_1269.field_5812;
                        if (!be.unwrapBox(stack.method_7972(), true))
                            return class_1269.field_5812;
                        be.unwrapBox(stack.method_7972(), false);
                        be.triggerStockCheck();
                        stack.method_7934(1);
                        AllSoundEvents.DEPOT_PLOP.playOnServer(level, pos);
                        if (stack.method_7960())
                            player.method_6122(hand, class_1799.field_8037);
                        return class_1269.field_5812;
                    }
                    return class_1269.field_5812;
                }
                if (be.animationTicks > 0)
                    return class_1269.field_5812;
                if (!level.method_8608()) {
                    player.method_31548().method_7398(be.heldBox.method_7972());
                    player.method_73183().method_8396(
                        null,
                        player.method_24515(),
                        class_3417.field_15197,
                        class_3419.field_15248,
                        .2f,
                        1f + player.method_73183().field_9229.method_43057()
                    );
                    be.heldBox = class_1799.field_8037;
                    be.notifyUpdate();
                }
                return class_1269.field_5812;
            }
        ).method_23665())
            return class_1269.field_5812;

        return class_1269.field_5812;
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder.method_11667(POWERED, LINKED));
    }

    @Override
    public void onNeighborChange(class_2680 state, class_4538 level, class_2338 pos, class_2338 neighbor) {
        if (neighbor.method_10093(state.method_61767(field_10927, class_2350.field_11036)).equals(pos))
            withBlockEntityDo(level, pos, PackagerBlockEntity::triggerStockCheck);
    }

    @Override
    public void neighborUpdate(class_2680 state, class_1937 worldIn, class_2338 pos, class_2248 sourceBlock, class_2338 fromPos, boolean isMoving) {
        if (worldIn.method_8608())
            return;
        InvManipulationBehaviour behaviour = BlockEntityBehaviour.get(worldIn, pos, InvManipulationBehaviour.TYPE);
        if (behaviour != null)
            behaviour.onNeighborChanged(fromPos);
    }

    @Override
    public void method_9612(
        class_2680 state,
        class_1937 worldIn,
        class_2338 pos,
        class_2248 blockIn,
        @Nullable class_9904 wireOrientation,
        boolean isMoving
    ) {
        if (worldIn.method_8608())
            return;
        boolean previouslyPowered = state.method_11654(POWERED);
        if (previouslyPowered == worldIn.method_49803(pos))
            return;
        worldIn.method_8652(pos, state.method_28493(POWERED), class_2248.field_31028);
        if (!previouslyPowered)
            withBlockEntityDo(worldIn, pos, PackagerBlockEntity::activate);
    }

    @Override
    public boolean shouldCheckWeakPower(class_2680 state, class_8235 level, class_2338 pos, class_2350 side) {
        return false;
    }

    @Override
    public Class<PackagerBlockEntity> getBlockEntityClass() {
        return PackagerBlockEntity.class;
    }

    @Override
    public class_2591<? extends PackagerBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.PACKAGER;
    }

    @Override
    protected boolean method_9516(class_2680 state, class_10 pathComputationType) {
        return false;
    }

    @Override
    public boolean method_9498(class_2680 pState) {
        return true;
    }

    @Override
    public int method_9572(class_2680 pState, class_1937 pLevel, class_2338 pPos, class_2350 direction) {
        return getBlockEntityOptional(pLevel, pPos).map(pbe -> {
            boolean empty = pbe.inventory.getStack().method_7960();
            if (pbe.animationTicks != 0)
                empty = false;
            return empty ? 0 : 15;
        }).orElse(0);
    }

}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/content/logistics/packager/PackagerBlock.java <==
package com.zurrtum.create.content.logistics.packager;

import com.zurrtum.create.AllBlockEntityTypes;
import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.AllItems;
import com.zurrtum.create.AllSoundEvents;
import com.zurrtum.create.api.entity.FakePlayerHandler;
import com.zurrtum.create.content.equipment.wrench.IWrenchable;
import com.zurrtum.create.content.logistics.box.PackageItem;
import com.zurrtum.create.foundation.advancement.AdvancementBehaviour;
import com.zurrtum.create.foundation.block.*;
import com.zurrtum.create.foundation.blockEntity.behaviour.BlockEntityBehaviour;
import com.zurrtum.create.foundation.blockEntity.behaviour.inventory.InvManipulationBehaviour;
import com.zurrtum.create.foundation.item.ItemHelper;
import com.zurrtum.create.infrastructure.items.ItemInventoryProvider;
import net.minecraft.class_10;
import net.minecraft.class_1263;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2561;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_8235;
import net.minecraft.class_9904;
import org.jetbrains.annotations.Nullable;

public class PackagerBlock extends WrenchableDirectionalBlock implements IBE<PackagerBlockEntity>, IWrenchable, ItemInventoryProvider<PackagerBlockEntity>, NeighborChangeListeningBlock, WeakPowerControlBlock, NeighborUpdateListeningBlock {

    public static final class_2746 POWERED = class_2741.field_12484;
    public static final class_2746 LINKED = class_2746.method_11825("linked");

    public PackagerBlock(class_2251 properties) {
        super(properties);
        class_2680 defaultBlockState = method_9564();
        if (defaultBlockState.method_28498(LINKED))
            defaultBlockState = defaultBlockState.method_11657(LINKED, false);
        method_9590(defaultBlockState.method_11657(POWERED, false));
    }

    @Override
    public class_1263 getInventory(class_1936 world, class_2338 pos, class_2680 state, PackagerBlockEntity blockEntity, class_2350 context) {
        return blockEntity.inventory;
    }

    @Override
    public void method_9567(class_1937 pLevel, class_2338 pPos, class_2680 pState, class_1309 pPlacer, class_1799 pStack) {
        super.method_9567(pLevel, pPos, pState, pPlacer, pStack);
        AdvancementBehaviour.setPlacedBy(pLevel, pPos, pPlacer);
    }

    @Override
    public class_2680 method_9605(class_1750 context) {
        class_2350 preferredFacing = null;
        for (class_2350 face : context.method_7718()) {
            class_2338 pos = context.method_8037().method_10093(face);
            class_2586 be = context.method_8045().method_8321(pos);
            if (be instanceof PackagerBlockEntity)
                continue;
            if (be != null && be.method_11002() && ItemHelper.getInventory(be.method_10997(), pos, null, be, null) != null) {
                preferredFacing = face.method_10153();
                break;
            }
        }

        class_1657 player = context.method_8036();
        if (preferredFacing == null) {
            class_2350 facing = context.method_7715();
            preferredFacing = player != null && player.method_5715() ? facing : facing.method_10153();
        }

        if (player != null && !(FakePlayerHandler.has(player))) {
            if (context.method_8045().method_8320(context.method_8037().method_10093(preferredFacing.method_10153()))
                .method_27852(AllBlocks.PORTABLE_STORAGE_INTERFACE)) {
                player.method_7353(class_2561.method_43471("create.packager.no_portable_storage"), true);
                return null;
            }
        }

        return super.method_9605(context).method_11657(POWERED, context.method_8045().method_49803(context.method_8037()))
            .method_11657(field_10927, preferredFacing);
    }

    @Override
    protected class_1269 method_55765(
        class_1799 stack,
        class_2680 state,
        class_1937 level,
        class_2338 pos,
        class_1657 player,
        class_1268 hand,
        class_3965 hitResult
    ) {
        if (stack.method_31574(AllItems.WRENCH))
            return class_1269.field_52423;
        if (stack.method_31574(AllItems.FACTORY_GAUGE))
            return class_1269.field_52423;
        if (stack.method_31574(AllItems.STOCK_LINK) && !(state.method_28498(LINKED) && state.method_11654(LINKED)))
            return class_1269.field_52423;
        if (stack.method_31574(AllItems.PACKAGE_FROGPORT))
            return class_1269.field_52423;

        if (onBlockEntityUseItemOn(
            level, pos, be -> {
                if (be.heldBox.method_7960()) {
                    if (be.animationTicks > 0)
                        return class_1269.field_5812;
                    if (PackageItem.isPackage(stack)) {
                        if (level.method_8608())
                            return class_1269.field_5812;
                        if (!be.unwrapBox(stack.method_7972(), true))
                            return class_1269.field_5812;
                        be.unwrapBox(stack.method_7972(), false);
                        be.triggerStockCheck();
                        stack.method_7934(1);
                        AllSoundEvents.DEPOT_PLOP.playOnServer(level, pos);
                        if (stack.method_7960())
                            player.method_6122(hand, class_1799.field_8037);
                        return class_1269.field_5812;
                    }
                    return class_1269.field_5812;
                }
                if (be.animationTicks > 0)
                    return class_1269.field_5812;
                if (!level.method_8608()) {
                    player.method_31548().method_7398(be.heldBox.method_7972());
                    player.method_37908().method_8396(
                        null,
                        player.method_24515(),
                        class_3417.field_15197,
                        class_3419.field_15248,
                        .2f,
                        1f + player.method_37908().field_9229.method_43057()
                    );
                    be.heldBox = class_1799.field_8037;
                    be.notifyUpdate();
                }
                return class_1269.field_5812;
            }
        ).method_23665())
            return class_1269.field_5812;

        return class_1269.field_5812;
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder.method_11667(POWERED, LINKED));
    }

    @Override
    public void onNeighborChange(class_2680 state, class_4538 level, class_2338 pos, class_2338 neighbor) {
        if (neighbor.method_10093(state.method_61767(field_10927, class_2350.field_11036)).equals(pos))
            withBlockEntityDo(level, pos, PackagerBlockEntity::triggerStockCheck);
    }

    @Override
    public void neighborUpdate(class_2680 state, class_1937 worldIn, class_2338 pos, class_2248 sourceBlock, class_2338 fromPos, boolean isMoving) {
        if (worldIn.field_9236)
            return;
        InvManipulationBehaviour behaviour = BlockEntityBehaviour.get(worldIn, pos, InvManipulationBehaviour.TYPE);
        if (behaviour != null)
            behaviour.onNeighborChanged(fromPos);
    }

    @Override
    public void method_9612(
        class_2680 state,
        class_1937 worldIn,
        class_2338 pos,
        class_2248 blockIn,
        @Nullable class_9904 wireOrientation,
        boolean isMoving
    ) {
        if (worldIn.field_9236)
            return;
        boolean previouslyPowered = state.method_11654(POWERED);
        if (previouslyPowered == worldIn.method_49803(pos))
            return;
        worldIn.method_8652(pos, state.method_28493(POWERED), class_2248.field_31028);
        if (!previouslyPowered)
            withBlockEntityDo(worldIn, pos, PackagerBlockEntity::activate);
    }

    @Override
    public boolean shouldCheckWeakPower(class_2680 state, class_8235 level, class_2338 pos, class_2350 side) {
        return false;
    }

    @Override
    public Class<PackagerBlockEntity> getBlockEntityClass() {
        return PackagerBlockEntity.class;
    }

    @Override
    public class_2591<? extends PackagerBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.PACKAGER;
    }

    @Override
    protected boolean method_9516(class_2680 state, class_10 pathComputationType) {
        return false;
    }

    @Override
    public boolean method_9498(class_2680 pState) {
        return true;
    }

    @Override
    public int method_9572(class_2680 pState, class_1937 pLevel, class_2338 pPos) {
        return getBlockEntityOptional(pLevel, pPos).map(pbe -> {
            boolean empty = pbe.inventory.getStack().method_7960();
            if (pbe.animationTicks != 0)
                empty = false;
            return empty ? 0 : 15;
        }).orElse(0);
    }

}
